IconifyArcticonsIconSetN class

Class to access the icon data for Arcticons. All icons are stored as static const strings. This class contains the icons that start with "N".

Constructors

IconifyArcticonsIconSetN()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

n11 → const String
preview
n26 → const String
preview
nab → const String
preview
nabla → const String
preview
nachoNotch → const String
preview
naerboks → const String
preview
nafath → const String
preview
nagad → const String
preview
nagopyAplin → const String
preview
namecheap → const String
preview
namelessCat → const String
preview
namida → const String
preview
nammaYatri → const String
preview
nani → const String
preview
nanji → const String
preview
nanoleaf → const String
preview
nanoloop → const String
preview
napster → const String
preview
naptime → const String
preview
naranjaX → const String
preview
naroth → const String
preview
nasa → const String
preview
nasaImageryFetcher → const String
preview
nassauLibrarySystem → const String
preview
nate → const String
preview
nationalRail → const String
preview
nationwide → const String
preview
nativeA → const String
preview
nativeAlpha → const String
preview
natrium → const String
preview
naturalCycles → const String
preview
naturalhour → const String
preview
naturalreader → const String
preview
natwest → const String
preview
naukricom → const String
preview
preview
preview
preview
preview
preview
preview
preview
preview
preview
preview
preview
preview
nayapay → const String
preview
nayateljoy → const String
preview
nayatv → const String
preview
nayto → const String
preview
nba → const String
preview
nba2k20 → const String
preview
nba2kMobile → const String
preview
nbaLive → const String
preview
nbc → const String
preview
ncalc → const String
preview
ncat → const String
preview
ncellApp → const String
preview
ncertBook → const String
preview
ncertBooksAndSolutions → const String
preview
nclient → const String
preview
ncp → const String
preview
ncPasswords → const String
preview
ndax → const String
preview
ndbNeos → const String
preview
nDial → const String
preview
nds4droid → const String
preview
nearbySharingWindows → const String
preview
neato → const String
preview
nebbiaKwgt → const String
preview
nebenanDe → const String
preview
nebula → const String
preview
nebulaIconPack → const String
preview
nebulo → const String
preview
nebulousIo → const String
preview
nect → const String
preview
nectar → const String
preview
nectwallet → const String
preview
nedComics → const String
preview
nedirNeDemek → const String
preview
neeva → const String
preview
nekkoto → const String
preview
neko → const String
preview
neko2 → const String
preview
nekoAtsume → const String
preview
nekoAtsume2 → const String
preview
nekoAtsumeAlt1 → const String
preview
nekoAtsumeAlt2 → const String
preview
nekoAtsumeAlt3 → const String
preview
nekobox → const String
preview
nekogotchi → const String
preview
nekogotchiAlt → const String
preview
nekogotchiAlt2 → const String
preview
nekogramx → const String
preview
nekogramxXeye → const String
preview
nekome → const String
preview
nemId → const String
preview
nemid → const String
preview
neoBackup → const String
preview
neobt → const String
preview
neochat → const String
preview
neoemu → const String
preview
neoFeed → const String
preview
neoLauncher → const String
preview
neolife → const String
preview
neon → const String
preview
neon1 → const String
preview
neonnext → const String
preview
neoStore → const String
preview
neostumbler → const String
preview
neoterm → const String
preview
nequiColombia → const String
preview
nerdAi → const String
preview
nerv → const String
preview
nesemu → const String
preview
neshan → const String
preview
nesnezeno → const String
preview
nesoid → const String
preview
nespresso → const String
preview
nest → const String
preview
nestbank → const String
preview
netAnalyzer → const String
preview
netbenefits → const String
preview
neteasecloudmusic → const String
preview
neteaseMail → const String
preview
neteaseMailMaster → const String
preview
neteaseOpenClass → const String
preview
netflix → const String
preview
netgearNighthawk → const String
preview
netGeneration → const String
preview
netguard → const String
preview
nethack → const String
preview
nethunter → const String
preview
nethunterKex → const String
preview
netiqAdvancedAuthentication → const String
preview
netmeds → const String
preview
netmirror → const String
preview
netmonitor → const String
preview
netmonster → const String
preview
netschool → const String
preview
netshoes → const String
preview
netspeedIndicator → const String
preview
netto → const String
preview
nettoApp → const String
preview
netwing → const String
preview
network → const String
preview
networkCellInfoAndWifi → const String
preview
networkmapper → const String
preview
networkSpeed → const String
preview
networksurvey → const String
preview
networkTools → const String
preview
networkToolsLibrary → const String
preview
networkUtilities → const String
preview
netx → const String
preview
netzclub → const String
preview
neumorphicCalculator → const String
preview
neuralCloud → const String
preview
neuralnetworksimulator → const String
preview
neuroLaunch → const String
preview
neutrinotes → const String
preview
neutronPlayer → const String
preview
neutronRecorder → const String
preview
nevertoomanybooks → const String
preview
newbMobileBanking → const String
preview
newegg → const String
preview
newLauncher → const String
preview
newpipe → const String
preview
news → const String
preview
news12 → const String
preview
newsasfacts → const String
preview
newsblur → const String
preview
newsbreak → const String
preview
newsMailRu → const String
preview
newsout → const String
preview
newsprovider → const String
preview
newsreader → const String
preview
newWorld → const String
preview
nexaIconPack → const String
preview
nexoWallet → const String
preview
next → const String
preview
nextbike → const String
preview
nextclodPasswords → const String
preview
nextcloud → const String
preview
nextcloudbookmarks → const String
preview
nextcloudCookbook → const String
preview
nextclouddev → const String
preview
nextcloudNews → const String
preview
nextcloudnotes → const String
preview
nextcloudServices → const String
preview
nextcloudsms → const String
preview
nextcloudTables → const String
preview
nextcloudtalk → const String
preview
nextdns → const String
preview
nextdnsManager → const String
preview
nextdoor → const String
preview
nextpass → const String
preview
nextPlayer → const String
preview
nextpush → const String
preview
nexttracks → const String
preview
nexus → const String
preview
nfcgate → const String
preview
nfcReader → const String
preview
nfcreader → const String
preview
nfcTasks → const String
preview
nfctools → const String
preview
nfsee → const String
preview
nfsNoLimits → const String
preview
ngaClient → const String
preview
ngl → const String
preview
ngpemu → const String
preview
nhbooks → const String
preview
nhkWorldJapan → const String
preview
nhl → const String
preview
nhsapp → const String
preview
nhSmart → const String
preview
niagaraLauncher → const String
preview
niagaraLauncherAlt → const String
preview
niagaraLauncherPro → const String
preview
niagaraLauncherRecentlyInstalled → const String
preview
niagaraLauncherSettings → const String
preview
niagaraWidgetsForKwgt → const String
preview
nice → const String
preview
niceCatch → const String
preview
nicefeed → const String
preview
nicehash → const String
preview
nicelock → const String
preview
niceMindMap → const String
preview
niconico → const String
preview
niconicoLive → const String
preview
niconicoManga → const String
preview
nidaUapp → const String
preview
nighthawk → const String
preview
nightLight → const String
preview
nightmode → const String
preview
nightowl → const String
preview
nightscreen → const String
preview
nightwavePlaza → const String
preview
nihonoari → const String
preview
niimbot → const String
preview
nike → const String
preview
nikeRunClub → const String
preview
nikeTrainingClub → const String
preview
nikke → const String
preview
nimcPersonalId → const String
preview
nimoTv → const String
preview
nina → const String
preview
nine → const String
preview
ning → const String
preview
ninjaArashi → const String
preview
ninjaArashi2 → const String
preview
nintendo → const String
preview
nintendoAlt1 → const String
preview
nintendoMusic → const String
preview
nintendoSwitchOnline → const String
preview
nintendoSwitchParentalControls → const String
preview
nissan → const String
preview
nissay → const String
preview
nitroNation → const String
preview
niyox → const String
preview
njTransit → const String
preview
njuskalo → const String
preview
nlweer → const String
preview
nlziet → const String
preview
nmacAccountManager → const String
preview
nmapWrapper → const String
preview
noaaWeatherUnofficial → const String
preview
noBeep → const String
preview
nobroker → const String
preview
nobrokerhood → const String
preview
nodevideo → const String
preview
noFap → const String
preview
nofasel → const String
preview
nofbeventscraper → const String
preview
noHumanity → const String
preview
noice → const String
preview
noicePodcastAndRadio → const String
preview
noisecapture → const String
preview
noisefit → const String
preview
noiseReducer → const String
preview
nokAir → const String
preview
nokiaLearn → const String
preview
nokiaWifi → const String
preview
nokiaWireless → const String
preview
nokoprint → const String
preview
nomachine → const String
preview
nomad → const String
preview
noMansSky → const String
preview
nonocross → const String
preview
nonogram → const String
preview
nontonAnime → const String
preview
noodlesAndCompany → const String
preview
noonShopping → const String
preview
noorulhuda → const String
preview
nordea → const String
preview
nordeaId → const String
preview
nordicfuzzcon → const String
preview
nordicNoodle → const String
preview
nordlayer → const String
preview
nordlockerCloud → const String
preview
nordnet → const String
preview
nordpass → const String
preview
nordvpn → const String
preview
norisbank → const String
preview
normal → const String
preview
normalAlt → const String
preview
norootFirewall → const String
preview
norton360 → const String
preview
nortonAppLock → const String
preview
nortonclean → const String
preview
nortonLifelockIdentity → const String
preview
nortonPasswordManager → const String
preview
norwegian → const String
preview
nos → const String
preview
nosTeletekst → const String
preview
nostraMap → const String
preview
nostrid → const String
preview
nosurfreddit → const String
preview
notable → const String
preview
notablePlus → const String
preview
notally → const String
preview
note → const String
preview
notebloc → const String
preview
notebook → const String
preview
notecryptpro → const String
preview
notein → const String
preview
noteIt → const String
preview
noteit → const String
preview
noteless → const String
preview
notepad → const String
preview
noterly → const String
preview
notes → const String
preview
notes2 → const String
preview
noteshelf → const String
preview
notesnook → const String
preview
notesnookAlt → const String
preview
noteToSelf → const String
preview
notewise → const String
preview
noThanks → const String
preview
nothingAdaptiveIconPack → const String
preview
nothingButWallpapers → const String
preview
nothingCamera → const String
preview
nothingGallery → const String
preview
nothingIconPack → const String
preview
nothingIcons → const String
preview
nothingLauncher → const String
preview
nothingMaterialIconPack → const String
preview
nothingRecorder → const String
preview
nothingSystemService → const String
preview
nothingWallpapers → const String
preview
nothingWeather → const String
preview
nothingWeatherAlt → const String
preview
nothingX → const String
preview
noti → const String
preview
notificationcron → const String
preview
notificationDictionary → const String
preview
notificationlog → const String
preview
notificationNotes → const String
preview
notificationnotes → const String
preview
notifications → const String
preview
notificheMeteo → const String
preview
notifyformiband → const String
preview
notiguy → const String
preview
notion → const String
preview
notionCalendar1 → const String
preview
notionCalendar2 → const String
preview
notionCalendar3 → const String
preview
notionCalendar4 → const String
preview
notionCalendar5 → const String
preview
notionCalendar6 → const String
preview
notionCalendar7 → const String
preview
notionCalendar8 → const String
preview
notionCalendar9 → const String
preview
notionCalendar10 → const String
preview
notionCalendar11 → const String
preview
notionCalendar12 → const String
preview
notionCalendar13 → const String
preview
notionCalendar14 → const String
preview
notionCalendar15 → const String
preview
notionCalendar16 → const String
preview
notionCalendar17 → const String
preview
notionCalendar18 → const String
preview
notionCalendar19 → const String
preview
notionCalendar20 → const String
preview
notionCalendar21 → const String
preview
notionCalendar22 → const String
preview
notionCalendar23 → const String
preview
notionCalendar24 → const String
preview
notionCalendar25 → const String
preview
notionCalendar26 → const String
preview
notionCalendar27 → const String
preview
notionCalendar28 → const String
preview
notionCalendar29 → const String
preview
notionCalendar30 → const String
preview
notionCalendar31 → const String
preview
notistar → const String
preview
nova → const String
preview
novaAmerica → const String
preview
novaGoogleCompanion → const String
preview
novaIconPack → const String
preview
novaIconPack2 → const String
preview
novaLauncher → const String
preview
novaLauncherPrime → const String
preview
novaPost → const String
preview
novaTelekommunications → const String
preview
novavideo → const String
preview
novaVideoPlayer → const String
preview
novelworld → const String
preview
nowplaying4droid → const String
preview
nowPlayingHistory → const String
preview
noxcleaner → const String
preview
nperf → const String
preview
npo → const String
preview
npoRadio1 → const String
preview
npoRadio2 → const String
preview
npoRadio3 → const String
preview
npoRadio4 → const String
preview
npoRadio5 → const String
preview
npr → const String
preview
nps → const String
preview
nrc → const String
preview
nrfConnect → const String
preview
nrfLogger → const String
preview
nrfToolbox → const String
preview
nrk → const String
preview
nrkRadio → const String
preview
nrkTv → const String
preview
ns → const String
preview
nsUsbloader → const String
preview
ntCalculadora → const String
preview
ntes → const String
preview
ntfy → const String
preview
ntodotxt → const String
preview
ntv → const String
preview
nubank → const String
preview
nuCarnival → const String
preview
nuclear → const String
preview
nucleusamdc → const String
preview
nucleusSmart → const String
preview
nuClient → const String
preview
nuinvest → const String
preview
nuki → const String
preview
nullsBrawl → const String
preview
nullsRoyale → const String
preview
number0 → const String
preview
number1 → const String
preview
number2 → const String
preview
number3 → const String
preview
number4 → const String
preview
number5 → const String
preview
number6 → const String
preview
number7 → const String
preview
number8 → const String
preview
number9 → const String
preview
number10 → const String
preview
numberCircle0 → const String
preview
numberCircle1 → const String
preview
numberCircle2 → const String
preview
numberCircle3 → const String
preview
numberCircle4 → const String
preview
numberCircle5 → const String
preview
numberCircle6 → const String
preview
numberCircle7 → const String
preview
numberCircle8 → const String
preview
numberCircle9 → const String
preview
numberCircle10 → const String
preview
numberhub → const String
preview
numberogram → const String
preview
numbersEsAp → const String
preview
numerica → const String
preview
numero → const String
preview
nuNl → const String
preview
nunti → const String
preview
nuOnline → const String
preview
nuroMobile → const String
preview
nvidia → const String
preview
nwsnow → const String
preview
nxt → const String
preview
nykaaman → const String
preview
nyonDark → const String
preview
nyonMaterialYouIcons → const String
preview
nyRangers → const String
preview
nytimes → const String
preview
nyx → const String
preview
nyYankees → const String
preview
nzb360 → const String
preview
nzblood → const String
preview
nzTides → const String
preview