IconifyArcticonsIconSetN class
Class to access the icon data for Arcticons. All icons are stored as static const strings. This class contains the icons that start with "N".
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- n11 → const String
-
- n26 → const String
-
- nab → const String
-
- nabla → const String
-
- nachoNotch → const String
-
- naerboks → const String
-
- nafath → const String
-
- nagad → const String
-
- nagopyAplin → const String
-
- namecheap → const String
-
- namelessCat → const String
-
- namida → const String
-
- nammaYatri → const String
-
- nani → const String
-
- nanji → const String
-
- nanoleaf → const String
-
- nanoloop → const String
-
- napster → const String
-
- naptime → const String
-
- naranjaX → const String
-
- naroth → const String
-
- nasa → const String
-
- nasaImageryFetcher → const String
-
- nassauLibrarySystem → const String
-
- nate → const String
-
- nationalRail → const String
-
- nationwide → const String
-
- nativeA → const String
-
- nativeAlpha → const String
-
- natrium → const String
-
- naturalCycles → const String
-
- naturalhour → const String
-
- naturalreader → const String
-
- natwest → const String
-
- naukricom → const String
-
-
-
-
-
-
-
-
-
-
-
-
-
- nayapay → const String
-
- nayateljoy → const String
-
- nayatv → const String
-
- nayto → const String
-
- nba → const String
-
- nba2k20 → const String
-
- nba2kMobile → const String
-
- nbaLive → const String
-
- nbc → const String
-
- ncalc → const String
-
- ncat → const String
-
- ncellApp → const String
-
- ncertBook → const String
-
- ncertBooksAndSolutions → const String
-
- nclient → const String
-
- ncp → const String
-
- ncPasswords → const String
-
- ndax → const String
-
- ndbNeos → const String
-
- nDial → const String
-
- nds4droid → const String
-
- nearbySharingWindows → const String
-
- neato → const String
-
- nebbiaKwgt → const String
-
- nebenanDe → const String
-
- nebula → const String
-
- nebulaIconPack → const String
-
- nebulo → const String
-
- nebulousIo → const String
-
- nect → const String
-
- nectar → const String
-
- nectwallet → const String
-
- nedComics → const String
-
- nedirNeDemek → const String
-
- neeva → const String
-
- nekkoto → const String
-
- neko → const String
-
- neko2 → const String
-
- nekoAtsume → const String
-
- nekoAtsume2 → const String
-
- nekoAtsumeAlt1 → const String
-
- nekoAtsumeAlt2 → const String
-
- nekoAtsumeAlt3 → const String
-
- nekobox → const String
-
- nekogotchi → const String
-
- nekogotchiAlt → const String
-
- nekogotchiAlt2 → const String
-
- nekogramx → const String
-
- nekogramxXeye → const String
-
- nekome → const String
-
- nemId → const String
-
- nemid → const String
-
- neoBackup → const String
-
- neobt → const String
-
- neochat → const String
-
- neoemu → const String
-
- neoFeed → const String
-
- neoLauncher → const String
-
- neolife → const String
-
- neon → const String
-
- neon1 → const String
-
- neonnext → const String
-
- neoStore → const String
-
- neostumbler → const String
-
- neoterm → const String
-
- nequiColombia → const String
-
- nerdAi → const String
-
- nerv → const String
-
- nesemu → const String
-
- neshan → const String
-
- nesnezeno → const String
-
- nesoid → const String
-
- nespresso → const String
-
- nest → const String
-
- nestbank → const String
-
- netAnalyzer → const String
-
- netbenefits → const String
-
- neteasecloudmusic → const String
-
- neteaseMail → const String
-
- neteaseMailMaster → const String
-
- neteaseOpenClass → const String
-
- netflix → const String
-
- netgearNighthawk → const String
-
- netGeneration → const String
-
- netguard → const String
-
- nethack → const String
-
- nethunter → const String
-
- nethunterKex → const String
-
- netiqAdvancedAuthentication → const String
-
- netmeds → const String
-
- netmirror → const String
-
- netmonitor → const String
-
- netmonster → const String
-
- netschool → const String
-
- netshoes → const String
-
- netspeedIndicator → const String
-
- netto → const String
-
- nettoApp → const String
-
- netwing → const String
-
- network → const String
-
- networkCellInfoAndWifi → const String
-
- networkmapper → const String
-
- networkSpeed → const String
-
- networksurvey → const String
-
- networkTools → const String
-
- networkToolsLibrary → const String
-
- networkUtilities → const String
-
- netx → const String
-
- netzclub → const String
-
- neumorphicCalculator → const String
-
- neuralCloud → const String
-
- neuralnetworksimulator → const String
-
- neuroLaunch → const String
-
- neutrinotes → const String
-
- neutronPlayer → const String
-
- neutronRecorder → const String
-
- nevertoomanybooks → const String
-
- newbMobileBanking → const String
-
- newegg → const String
-
- newLauncher → const String
-
- newpipe → const String
-
- news → const String
-
- news12 → const String
-
- newsasfacts → const String
-
- newsblur → const String
-
- newsbreak → const String
-
- newsMailRu → const String
-
- newsout → const String
-
- newsprovider → const String
-
- newsreader → const String
-
- newWorld → const String
-
- nexaIconPack → const String
-
- nexoWallet → const String
-
- next → const String
-
- nextbike → const String
-
- nextclodPasswords → const String
-
- nextcloud → const String
-
- nextcloudbookmarks → const String
-
- nextcloudCookbook → const String
-
- nextclouddev → const String
-
- nextcloudNews → const String
-
- nextcloudnotes → const String
-
- nextcloudServices → const String
-
- nextcloudsms → const String
-
- nextcloudTables → const String
-
- nextcloudtalk → const String
-
- nextdns → const String
-
- nextdnsManager → const String
-
- nextdoor → const String
-
- nextpass → const String
-
- nextPlayer → const String
-
- nextpush → const String
-
- nexttracks → const String
-
- nexus → const String
-
- nfcgate → const String
-
- nfcReader → const String
-
- nfcreader → const String
-
- nfcTasks → const String
-
- nfctools → const String
-
- nfsee → const String
-
- nfsNoLimits → const String
-
- ngaClient → const String
-
- ngl → const String
-
- ngpemu → const String
-
- nhbooks → const String
-
- nhkWorldJapan → const String
-
- nhl → const String
-
- nhsapp → const String
-
- nhSmart → const String
-
- niagaraLauncher → const String
-
- niagaraLauncherAlt → const String
-
- niagaraLauncherPro → const String
-
- niagaraLauncherRecentlyInstalled → const String
-
- niagaraLauncherSettings → const String
-
- niagaraWidgetsForKwgt → const String
-
- nice → const String
-
- niceCatch → const String
-
- nicefeed → const String
-
- nicehash → const String
-
- nicelock → const String
-
- niceMindMap → const String
-
- niconico → const String
-
- niconicoLive → const String
-
- niconicoManga → const String
-
- nidaUapp → const String
-
- nighthawk → const String
-
- nightLight → const String
-
- nightmode → const String
-
- nightowl → const String
-
- nightscreen → const String
-
- nightwavePlaza → const String
-
- nihonoari → const String
-
- niimbot → const String
-
- nike → const String
-
- nikeRunClub → const String
-
- nikeTrainingClub → const String
-
- nikke → const String
-
- nimcPersonalId → const String
-
- nimoTv → const String
-
- nina → const String
-
- nine → const String
-
- ning → const String
-
- ninjaArashi → const String
-
- ninjaArashi2 → const String
-
- nintendo → const String
-
- nintendoAlt1 → const String
-
- nintendoMusic → const String
-
- nintendoSwitchOnline → const String
-
- nintendoSwitchParentalControls → const String
-
- nissan → const String
-
- nissay → const String
-
- nitroNation → const String
-
- niyox → const String
-
- njTransit → const String
-
- njuskalo → const String
-
- nlweer → const String
-
- nlziet → const String
-
- nmacAccountManager → const String
-
- nmapWrapper → const String
-
- noaaWeatherUnofficial → const String
-
- noBeep → const String
-
- nobroker → const String
-
- nobrokerhood → const String
-
- nodevideo → const String
-
- noFap → const String
-
- nofasel → const String
-
- nofbeventscraper → const String
-
- noHumanity → const String
-
- noice → const String
-
- noicePodcastAndRadio → const String
-
- noisecapture → const String
-
- noisefit → const String
-
- noiseReducer → const String
-
- nokAir → const String
-
- nokiaLearn → const String
-
- nokiaWifi → const String
-
- nokiaWireless → const String
-
- nokoprint → const String
-
- nomachine → const String
-
- nomad → const String
-
- noMansSky → const String
-
- nonocross → const String
-
- nonogram → const String
-
- nontonAnime → const String
-
- noodlesAndCompany → const String
-
- noonShopping → const String
-
- noorulhuda → const String
-
- nordea → const String
-
- nordeaId → const String
-
- nordicfuzzcon → const String
-
- nordicNoodle → const String
-
- nordlayer → const String
-
- nordlockerCloud → const String
-
- nordnet → const String
-
- nordpass → const String
-
- nordvpn → const String
-
- norisbank → const String
-
- normal → const String
-
- normalAlt → const String
-
- norootFirewall → const String
-
- norton360 → const String
-
- nortonAppLock → const String
-
- nortonclean → const String
-
- nortonLifelockIdentity → const String
-
- nortonPasswordManager → const String
-
- norwegian → const String
-
- nos → const String
-
- nosTeletekst → const String
-
- nostraMap → const String
-
- nostrid → const String
-
- nosurfreddit → const String
-
- notable → const String
-
- notablePlus → const String
-
- notally → const String
-
- note → const String
-
- notebloc → const String
-
- notebook → const String
-
- notecryptpro → const String
-
- notein → const String
-
- noteIt → const String
-
- noteit → const String
-
- noteless → const String
-
- notepad → const String
-
- noterly → const String
-
- notes → const String
-
- notes2 → const String
-
- noteshelf → const String
-
- notesnook → const String
-
- notesnookAlt → const String
-
- noteToSelf → const String
-
- notewise → const String
-
- noThanks → const String
-
- nothingAdaptiveIconPack → const String
-
- nothingButWallpapers → const String
-
- nothingCamera → const String
-
- nothingGallery → const String
-
- nothingIconPack → const String
-
- nothingIcons → const String
-
- nothingLauncher → const String
-
- nothingMaterialIconPack → const String
-
- nothingRecorder → const String
-
- nothingSystemService → const String
-
- nothingWallpapers → const String
-
- nothingWeather → const String
-
- nothingWeatherAlt → const String
-
- nothingX → const String
-
- noti → const String
-
- notificationcron → const String
-
- notificationDictionary → const String
-
- notificationlog → const String
-
- notificationNotes → const String
-
- notificationnotes → const String
-
- notifications → const String
-
- notificheMeteo → const String
-
- notifyformiband → const String
-
- notiguy → const String
-
- notion → const String
-
- notionCalendar1 → const String
-
- notionCalendar2 → const String
-
- notionCalendar3 → const String
-
- notionCalendar4 → const String
-
- notionCalendar5 → const String
-
- notionCalendar6 → const String
-
- notionCalendar7 → const String
-
- notionCalendar8 → const String
-
- notionCalendar9 → const String
-
- notionCalendar10 → const String
-
- notionCalendar11 → const String
-
- notionCalendar12 → const String
-
- notionCalendar13 → const String
-
- notionCalendar14 → const String
-
- notionCalendar15 → const String
-
- notionCalendar16 → const String
-
- notionCalendar17 → const String
-
- notionCalendar18 → const String
-
- notionCalendar19 → const String
-
- notionCalendar20 → const String
-
- notionCalendar21 → const String
-
- notionCalendar22 → const String
-
- notionCalendar23 → const String
-
- notionCalendar24 → const String
-
- notionCalendar25 → const String
-
- notionCalendar26 → const String
-
- notionCalendar27 → const String
-
- notionCalendar28 → const String
-
- notionCalendar29 → const String
-
- notionCalendar30 → const String
-
- notionCalendar31 → const String
-
- notistar → const String
-
- nova → const String
-
- novaAmerica → const String
-
- novaGoogleCompanion → const String
-
- novaIconPack → const String
-
- novaIconPack2 → const String
-
- novaLauncher → const String
-
- novaLauncherPrime → const String
-
- novaPost → const String
-
- novaTelekommunications → const String
-
- novavideo → const String
-
- novaVideoPlayer → const String
-
- novelworld → const String
-
- nowplaying4droid → const String
-
- nowPlayingHistory → const String
-
- noxcleaner → const String
-
- nperf → const String
-
- npo → const String
-
- npoRadio1 → const String
-
- npoRadio2 → const String
-
- npoRadio3 → const String
-
- npoRadio4 → const String
-
- npoRadio5 → const String
-
- npr → const String
-
- nps → const String
-
- nrc → const String
-
- nrfConnect → const String
-
- nrfLogger → const String
-
- nrfToolbox → const String
-
- nrk → const String
-
- nrkRadio → const String
-
- nrkTv → const String
-
- ns → const String
-
- nsUsbloader → const String
-
- ntCalculadora → const String
-
- ntes → const String
-
- ntfy → const String
-
- ntodotxt → const String
-
- ntv → const String
-
- nubank → const String
-
- nuCarnival → const String
-
- nuclear → const String
-
- nucleusamdc → const String
-
- nucleusSmart → const String
-
- nuClient → const String
-
- nuinvest → const String
-
- nuki → const String
-
- nullsBrawl → const String
-
- nullsRoyale → const String
-
- number0 → const String
-
- number1 → const String
-
- number2 → const String
-
- number3 → const String
-
- number4 → const String
-
- number5 → const String
-
- number6 → const String
-
- number7 → const String
-
- number8 → const String
-
- number9 → const String
-
- number10 → const String
-
- numberCircle0 → const String
-
- numberCircle1 → const String
-
- numberCircle2 → const String
-
- numberCircle3 → const String
-
- numberCircle4 → const String
-
- numberCircle5 → const String
-
- numberCircle6 → const String
-
- numberCircle7 → const String
-
- numberCircle8 → const String
-
- numberCircle9 → const String
-
- numberCircle10 → const String
-
- numberhub → const String
-
- numberogram → const String
-
- numbersEsAp → const String
-
- numerica → const String
-
- numero → const String
-
- nuNl → const String
-
- nunti → const String
-
- nuOnline → const String
-
- nuroMobile → const String
-
- nvidia → const String
-
- nwsnow → const String
-
- nxt → const String
-
- nykaaman → const String
-
- nyonDark → const String
-
- nyonMaterialYouIcons → const String
-
- nyRangers → const String
-
- nytimes → const String
-
- nyx → const String
-
- nyYankees → const String
-
- nzb360 → const String
-
- nzblood → const String
-
- nzTides → const String
-